% Solve SIR model using IE method
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%      Exact numerical integration of the master     %%%%%%%%%%%%
%%%%%%%%%%%       equation in some models of stochastic        %%%%%%%%%%%%
%%%%%%%%%%%                     epidemiology                   %%%%%%%%%%%%
%%%%%%%%%%%                      IE METHOD                     %%%%%%%%%%%%
%%%%%%%%%%%               Authors: Jenkinson/Goutsias          %%%%%%%%%%%%
%%%%%%%%%%%                Last Modified: 01/13/2012           %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

clear all;
close all;

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initialize simulation parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

tic;        % start timer

tau = 0.01; % time-step in days  
tf  = 25;   % simulation time in days

display('Running IE Method. Please wait...');

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initialize model parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

s0 = 762;            % initial number of susceptible individuals
i0 = 1;              % initial number of infected individuals 
r0 = 0;              % initial number of recovered individuals 

M  = 2;              % number of reactions

k1 = 0.00218;        % 1/day,  S + I -> 2I
k2 = 0.44036;        % 1/day,      I -> R
         
steps = tf/tau;    % number of steps

% determine sample space Z

hyperCubeOrigin = zeros(M,1); % origin of hypercube
hyperCubeExtent = [762;763];  % extent of hypercube
K               = 763*764;    % number of states

% define initial probability 

pPrev    = zeros(K,1);
pPrev(1) = 1;

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Solve system
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% find implicit Euler matrix
IminusTauA = genMatrix(k1,k2,s0,i0,K,hyperCubeOrigin,hyperCubeExtent,M,tau);

% perform implicit Euler solver steps

for index = 1:steps
    %
    % Do Euler solver steps
    %
    pNext = IminusTauA\pPrev; % matlab automatically performs recursive substitution
    pPrev = pNext;            % prepare for next time step

end

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Map Probability to SI plane
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

SIprobs = mapProbs(pNext,hyperCubeOrigin,hyperCubeExtent,s0,i0);

timeElapsed = toc;  % store CPU time

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute L2 error
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

load ../SIprobsGroundTruth.mat

FinalError = sqrt(sum(sum((SIprobsTruth-SIprobs).^2)));

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Save results to file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

saveResultsToFile;