% Generate (I-tau*A) matrix
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%      Exact numerical integration of the master     %%%%%%%%%%%%
%%%%%%%%%%%        equation in some models of stochastic       %%%%%%%%%%%%
%%%%%%%%%%%                     epidemiology                   %%%%%%%%%%%%
%%%%%%%%%%%              FIGURE GENERATION SOFTWARE            %%%%%%%%%%%%
%%%%%%%%%%%             Authors: Jenkinson/Goutsias            %%%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 01/13/2012             %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function IminusDeltaA = genMatrix(k1,k2,s0,i0,K,hyperCubeOrigin,...
                                  hyperCubeExtent,M,tau)

% find hypercube edge lengths
edge = 1+hyperCubeExtent-hyperCubeOrigin;

% initialize
nonZeroTotal    = K*(M+1);
nonZeroElements = zeros(nonZeroTotal,1);
rows            = nonZeroElements;
cols            = rows;

nonZeroCount = 1;
count = 1;
for z2=hyperCubeOrigin(2):hyperCubeExtent(2)
    for z1=hyperCubeOrigin(1):hyperCubeExtent(1)
        % compute current propensities
        alpha = propensity(z1,z2,k1,k2,s0,i0); 

        % find diagonal term
        rows(nonZeroCount)            = count;
        cols(nonZeroCount)            = count;
        nonZeroElements(nonZeroCount) = 1+tau*sum(alpha);
        nonZeroCount                  = nonZeroCount+1;

        % find m=1 off diagonal
        if alpha(1)>0
            rows(nonZeroCount)            = count+1;
            cols(nonZeroCount)            = count;
            nonZeroElements(nonZeroCount) = -tau*alpha(1);
            nonZeroCount                  = nonZeroCount+1;
        end

        % find m=2 off diagonal
        if alpha(2)>0
            rows(nonZeroCount)            = count+edge(1);
            cols(nonZeroCount)            = count;
            nonZeroElements(nonZeroCount) = -tau*alpha(2);
            nonZeroCount                  = nonZeroCount+1;
        end

        count = count+1;
        
    end
end

%generate sparse matrix
IminusDeltaA = sparse(rows(nonZeroElements~=0),cols(nonZeroElements~=0),...
                                  nonZeroElements(nonZeroElements~=0),K,K);